==> snaxdart_models-1.0.0.tar.gz: test/v1/sign_up_test.dart <==
import 'package:test/test.dart';

import 'package:snaxdart_models/v1.dart';
import 'package:snaxdart/snaxdart.dart';
import 'package:snaxdart_errors/snaxdart_errors.dart';

void main() {
  group('Sign Up Model', () {
    test('should create model with initial state', () {
      final signUp = SignUp.initialState();
      expect(signUp.error, null);
      expect(signUp.loading, false);
    });

    test('should create copy with loading', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(loading: true);

      expect(signUp.loading, true);
    });

    test('should create copy with error', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(error: new GeneralError('something wrong'));

      expect(signUp.error.message, ('something wrong'));
    });

    test('should set snax account', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(snaxAccount: 'snax_account');

      expect(signUp.snaxAccount, 'snax_account');
    });

    test('should set post id', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(postId: '123');

      expect(signUp.postId, '123');
    });

    test('should set confirmed', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(confirmed: true);

      expect(signUp.confirmed, true);
    });

    test('should set hash', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(hash: 'somehash');

      expect(signUp.hash, 'somehash');
    });

    test('should set bindingSalt', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(bindingSalt: 'somebindingSalt');

      expect(signUp.bindingSalt, 'somebindingSalt');
    });

    test('should set platform', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(platform: Platform.Steem);

      expect(signUp.platform, Platform.Steem);

      final signUp1 = initialSignUp.copyWith(platform: Platform.Twitter);

      expect(signUp1.platform,  Platform.Twitter);
    });

    test('should set snax account', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(snaxAccount: 'snax_account');

      expect(signUp.snaxAccount, 'snax_account');
    });

    test('should set hash', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(hash: 'somehash');

      expect(signUp.hash, 'somehash');
    });

    test('should set platform', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(platform: Platform.Steem);

      expect(signUp.platform, Platform.Steem);

      final signUp1 = initialSignUp.copyWith(platform: Platform.Twitter);

      expect(signUp1.platform,  Platform.Twitter);
    });

    test('should create copy with account', () {
      final initialSignUp = SignUp.initialState();

      final account = WalletAccount(
        snax: Account('hellosnax', 5),
        twitter: TwitterAccount(displayName: 'SnaxTwitter', id: "1"),
      );

      final signUp = initialSignUp.copyWith(account: account);

      expect(signUp.account.snax.accountName, 'hellosnax');
      expect(signUp.account.snax.headBlockNum, 5);
      expect(signUp.account.twitter.displayName, 'SnaxTwitter');
      expect(signUp.account.twitter.id, '1');
    });

    test('should reset error', () {
      final initialSignUp =
          SignUp.initialState().copyWith(error: new GeneralError('Random error'));

      final signUp = initialSignUp.reset();

      expect(signUp.error, null);
    });
  });
}

==> snaxdart_models-1.1.31.tar.gz: test/v1/sign_up_test.dart <==
import 'package:test/test.dart';

import 'package:snaxdart_models/v1.dart';
import 'package:snaxdart/snaxdart.dart';
import 'package:snaxdart_errors/snaxdart_errors.dart';

void main() {
  group('Sign Up Model', () {
    test('should create model with initial state', () {
      final signUp = SignUp.initialState();
      expect(signUp.error, null);
      expect(signUp.loading, false);
    });

    test('should create copy with loading', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(loading: true);

      expect(signUp.loading, true);
    });

    test('should create copy with error', () {
      final initialSignUp = SignUp.initialState();

      final signUp =
          initialSignUp.copyWith(error: new GeneralError('something wrong'));

      expect(signUp.error.message, ('something wrong'));
    });

    test('should set snax account', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(snaxAccount: 'snax_account');

      expect(signUp.snaxAccount, 'snax_account');
    });

    test('should set post id', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(postId: '123');

      expect(signUp.postId, '123');
    });

    test('should set confirmed', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(confirmed: true);

      expect(signUp.confirmed, true);
    });

    test('should set hash', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(hash: 'somehash');

      expect(signUp.hash, 'somehash');
    });

    test('should set bindingSalt', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(bindingSalt: 'somebindingSalt');

      expect(signUp.bindingSalt, 'somebindingSalt');
    });

    test('should set platform', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(platform: Platform.Steem);

      expect(signUp.platform, Platform.Steem);

      final signUp1 = initialSignUp.copyWith(platform: Platform.Twitter);

      expect(signUp1.platform, Platform.Twitter);
    });

    test('should set snax account', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(snaxAccount: 'snax_account');

      expect(signUp.snaxAccount, 'snax_account');
    });

    test('should set hash', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(hash: 'somehash');

      expect(signUp.hash, 'somehash');
    });

    test('should set platform', () {
      final initialSignUp = SignUp.initialState();

      final signUp = initialSignUp.copyWith(platform: Platform.Steem);

      expect(signUp.platform, Platform.Steem);

      final signUp1 = initialSignUp.copyWith(platform: Platform.Twitter);

      expect(signUp1.platform, Platform.Twitter);
    });

    test('should create copy with account', () {
      final initialSignUp = SignUp.initialState();

      final account = WalletAccount(
        snax: Account('hellosnax', 5),
        twitter: TwitterAccount(displayName: 'SnaxTwitter', id: "1"),
      );

      final signUp = initialSignUp.copyWith(account: account);

      expect(signUp.account.snax.accountName, 'hellosnax');
      expect(signUp.account.snax.headBlockNum, 5);
      expect(signUp.account.twitter.displayName, 'SnaxTwitter');
      expect(signUp.account.twitter.id, '1');
    });

    test('should reset error', () {
      final initialSignUp = SignUp.initialState()
          .copyWith(error: new GeneralError('Random error'));

      final signUp = initialSignUp.reset();

      expect(signUp.error, null);
    });
  });
}
